﻿/*****************************************************************************
 * Copyright (C) 2014 Microchip Technology Inc. and its subsidiaries
 * (Microchip).  All rights reserved.
 * 
 * You are permitted to use the software and its derivatives with Microchip
 * products. See the license agreement accompanying this software, if any,
 * for additional info regarding your rights and obligations.
 * 
 * SOFTWARE AND DOCUMENTATION ARE PROVIDED “AS IS” WITHOUT WARRANTY OF ANY
 * KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY
 * WARRANTY OF MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A
 * PARTICULAR PURPOSE. IN NO EVENT SHALL MICROCHIP OR ITS LICENSORS BE
 * LIABLE OR OBLIGATED UNDER CONTRACT, NEGLIGENCE, STRICT LIABILITY,
 * CONTRIBUTION, BREACH OF WARRANTY, OR OTHER LEGAL EQUITABLE THEORY FOR ANY
 * DIRECT OR INDIRECT DAMAGES OR EXPENSES INCLUDING BUT NOT LIMITED TO ANY
 * INCIDENTAL, SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES, OR OTHER SIMILAR
 * COSTS. To the fullest extend allowed by law, Microchip and its licensors
 * liability will not exceed the amount of fees that you paid directly to
 * Microchip to use this software or $1,000, whichever is greater.
 * 
 *****************************************************************************
 * Revision history:
 * 22.10.2013   Mihai Cuciuc    0.1     Communication with USB device functional,
 *                                      all DALI tests implemented.
 * 22.01.2014   Oana Barahtian  1.0     Changed the application to a multi-
 *                                      threaded model, restructured user
 *                                      interface and added functionality.
 */



using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using DALITestApplication.Classes;

namespace DALITestApplication.Classes
{
    public class Commands
    {
        public DataGridView listCommGrid = new DataGridView();
        public List<ListValue> listValues = new List<ListValue>();
        public List<DaliCommands> listDaliCommand = new List<DaliCommands>();

        public int rows = 0;

        public Commands() { }

        /**
         * Save dataGrid config to List<ListValue>
         */
        public void SaveLocalListConfiguration()
        {

            string commCell;
            bool sendCell = false;
            string timeCell;

            // clear the list
            listValues.Clear();

            for (int i = 0; i < rows; i++)
            {
                commCell = (string)listCommGrid.Rows[i].Cells[0].Value;
                sendCell = (bool)listCommGrid.Rows[i].Cells[1].Value;
                timeCell = (string)listCommGrid.Rows[i].Cells[2].Value;

                listValues.Add(new ListValue(commCell, sendCell, timeCell));
            }
        }

        // load from file (default_commands.txt) a default list configuration
        public void LoadDefaultCommands()
        {
            string[] text = System.IO.File.ReadAllLines(@"default_commands.txt");
            bool checkBox;

            for (int i = 0; i < text.Length; i++)
            {
                string[] row = text[i].Split('-');
                if (row[1] == "True")
                {
                    checkBox = true;
                }
                else
                {
                    checkBox = false;
                }
                // add the entry
               listCommGrid.Rows.Add(row[0], checkBox, row[2]);
            }
            rows = text.Length;

            SaveLocalListConfiguration();
        }

        public void LoadDaliCommands()
        {
            string[] text = System.IO.File.ReadAllLines(@"dali_commands.txt");
            bool addr, data, twice;
            int param;

            for (int i = 0; i < text.Length; i++)
            {
                // row[0] -> command name
                // row[1] -> map command
                // row[2] -> addressing (Y/N)
                // row[3] -> dataBit S (0/1)
                // row[4] -> parameterBites
                // row[5] -> default twice (Y/N)

                string[] row = text[i].Split('-');

                if (row[2] == "Y")
                {
                    addr = true;
                }
                else 
                {
                    addr = false;
                }

                if (row[3] == "1")
                {
                    data = true;
                }
                else
                {
                   data = false;
                }

                param = Convert.ToInt32(row[4]);

                if (row[5] == "Y")
                {
                    twice = true;
                }
                else
                {
                    twice = false;
                }

                listDaliCommand.Add(new DaliCommands(row[0], row[1], addr, data, param, twice));
            }
        }

        // Get the list configuration from List<Listvalue>
        public void GetLocalListConfiguration()
        {
            // clear dataGrid
            listCommGrid.Rows.Clear();
            listCommGrid.Refresh();
            rows = 0;

            // adding the values from List<ListValue>
            for (int i = 0; i < listValues.Count(); i++)
            {
                listCommGrid.Rows.Add(listValues[i].GetComm(), listValues[i].GetSend(), listValues[i].GetTime());
                rows++;
            }
        }

        // add a specific command to the grid
        public void AddRows(string str, bool value, string delay)
        {
            listCommGrid.Rows.Add(str, value, delay);
            rows++;
        }
    }
}
