﻿/*****************************************************************************
 * Copyright (C) 2014 Microchip Technology Inc. and its subsidiaries
 * (Microchip).  All rights reserved.
 * 
 * You are permitted to use the software and its derivatives with Microchip
 * products. See the license agreement accompanying this software, if any,
 * for additional info regarding your rights and obligations.
 * 
 * SOFTWARE AND DOCUMENTATION ARE PROVIDED “AS IS” WITHOUT WARRANTY OF ANY
 * KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY
 * WARRANTY OF MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A
 * PARTICULAR PURPOSE. IN NO EVENT SHALL MICROCHIP OR ITS LICENSORS BE
 * LIABLE OR OBLIGATED UNDER CONTRACT, NEGLIGENCE, STRICT LIABILITY,
 * CONTRIBUTION, BREACH OF WARRANTY, OR OTHER LEGAL EQUITABLE THEORY FOR ANY
 * DIRECT OR INDIRECT DAMAGES OR EXPENSES INCLUDING BUT NOT LIMITED TO ANY
 * INCIDENTAL, SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES, OR OTHER SIMILAR
 * COSTS. To the fullest extend allowed by law, Microchip and its licensors
 * liability will not exceed the amount of fees that you paid directly to
 * Microchip to use this software or $1,000, whichever is greater.
 * 
 *****************************************************************************
 * Revision history:
 * 22.10.2013   Mihai Cuciuc    0.1     Communication with USB device functional,
 *                                      all DALI tests implemented.
 * 22.01.2014   Oana Barahtian  1.0     Changed the application to a multi-
 *                                      threaded model, restructured user
 *                                      interface and added functionality.
 */



using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;
using System.Threading;
using System.Windows.Forms;

namespace DALITestApplication
{
    // This class is used for writing information to the output console while the tests are being run
    class Messages
    {
        public ToolStripMenuItem infoMenu = new ToolStripMenuItem();
        public ToolStripMenuItem debugMenu = new ToolStripMenuItem();
        public ToolStripMenuItem errorMenu= new ToolStripMenuItem();
        public ToolStripMenuItem messageMenu = new ToolStripMenuItem();

        public RichTextBox log = new RichTextBox();


        // In order to write lines to the console window in different colours, their starting and
        // ending positions within all the text in the textbox need to be known. Rather than
        // recomputing this for each new line (which gets slow when there's a lot of output), we
        // store the length of all the text in this variable and keep updating it.
        public int textBoxLen = 0;
        public int numErrors;

        public Form form = new Form();

        public void writeData(int start, int len, String text, Color c)
        {
            start = textBoxLen;
            len = text.Length;

            log.AppendText(text);
            log.SelectionStart = start;
            log.SelectionLength = len;
            log.SelectionColor = c;

            textBoxLen += len;
        }

        delegate void WriteTextCallback(string text, Color c);

        // This function is used for writing text on log.
        public void WriteText(string text, Color c)
        {
            // verify if log is invoked for writing
            if (log.InvokeRequired)
            {
                WriteTextCallback d = new WriteTextCallback(WriteText);
                form.Invoke(d, new object[] { text, c });
            }
            else
            {
                if (infoMenu.Checked == true)
                {
                    int start = 0, length = 0;
                    writeData(start, length, text, c);
                }
                else if (debugMenu.Checked == true)
                {
                    int start = 0, length = 0;
                    writeData(start, length, text, c);
                }
                else if (messageMenu.Checked == true)
                {
                    int start = 0, length = 0;
                    writeData(start, length, text, c);
                }
                else if (errorMenu.Checked == true)
                {
                    int start = 0, length = 0;
                    writeData(start, length, text, c);
                }
            }
        }

        public void Info(String s)
        {
            Info(s, Color.Black);
        }

        public void Info(String s, Color c)
        {
            if (infoMenu.Checked == true)
            {
                String line;
                line = DateTime.Now.ToString("[HH:mm:ss.ffff]") + " \tINFO   \t" + s + "\n";

                WriteText(line, c);
            }
        }

        public void Debug(String s)
        {
            Debug(s, Color.Black);
        }

        public void Debug(String s, Color c)
        {
            if (debugMenu.Checked == true)
            {
                String line;
                line = DateTime.Now.ToString("[HH:mm:ss.ffff]") + "\tDEBUG  \t" + s + "\n";

                WriteText(line, c);
            }
        }

        public void Error(String s)
        {
            Error(s, Color.Red);
        }

        public void Error(String s, Color c)
        {
            String line;
            line = DateTime.Now.ToString("[HH:mm:ss.ffff]") + "\tERROR  \t" + s + "\n";

            WriteText(line, c);

            numErrors++;

            if (errorMenu.Checked == true)
            {
                MessageBox.Show("Acknowledge", "Error");
            }
        }

        public void Summary(String s)
        {
            Summary(s, Color.Black);
        }

        public void Summary(String s, Color c)
        {
            String line;
            line = DateTime.Now.ToString("[HH:mm:ss.ffff]") + "\tSUMMARY\t" + s + "\n";

            WriteText(line, c);
        }

        public void Message(String s)
        {
            Message(s, Color.Black);
        }

        public void Message(String s, Color c)
        {
            if (messageMenu.Checked == true)
            {

                String line;
                line = DateTime.Now.ToString("[HH:mm:ss.ffff]") + "\tMESSAGE\t" + s + "\n";

                WriteText(line, c);
            }
        }

    }
}
